ActionChannel class
This class represents the channel that you are going to perfome actions Like:
channel.performAction(
action: 'send_message',
actionParams: { 'message': 'Hello private peeps! 😜' }
);
Constructors
- ActionChannel({required String identifier, required SendMessageCallback sendMessageCallback})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performAction(
String action, {Map< String, dynamic> ? params}) → void - If you need to perfome an action in your channel just call this method passing the name of your action that you need to call on server
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
) → void - If you need to unsubscribe
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited